@@ -25,6 +25,7 @@ except ImportError:
 
 from xml2rfc import strings, log
 from xml2rfc.util.date import extract_date, augment_date, format_date, get_expiry_date
+from xml2rfc.util.file import can_access, FileAccessError
 from xml2rfc.util.name import short_author_ascii_name_parts, full_author_name_expansion, short_author_name_parts
 from xml2rfc.util.unicode import is_svg
 from xml2rfc.utils import namespaces, find_duplicate_ids, slugify
@@ -76,7 +77,6 @@ default_options.__dict__ = {
         'id_html_archive_url': 'https://www.ietf.org/archive/id/',
         'id_reference_base_url': 'https://datatracker.ietf.org/doc/html/',
         'id_is_work_in_progress': True,
-        'image_svg': False,
         'indent': 2,
         'info': False,
         'info_base_url': 'https://www.rfc-editor.org/info/',
@@ -1727,7 +1727,6 @@ xref_tags   = get_xref_tags()
 class BaseV3Writer(object):
 
     def __init__(self, xmlrfc, quiet=None, options=default_options, date=None):
-        global v3_rnc_file, v3_rng_file, v3_schema
         self.xmlrfc = xmlrfc
         self.tree = xmlrfc.tree if xmlrfc else None
         self.root = self.tree.getroot() if xmlrfc else None
@@ -1804,7 +1803,7 @@ class BaseV3Writer(object):
     def get_relevant_pi(self, e, name):
         pis = self.get_relevant_pis(e)
         pi_list = list(filter(None, [ pi.get(name) for pi in pis ]))
-        return pi_list[-1] if pi_list else None
+        return pi_list[0] if pi_list else None
 
     def silenced(self, e, text):
         text = text.strip()
@@ -1829,7 +1828,7 @@ class BaseV3Writer(object):
                 self.log(self.msg(e, label, text))
 
     def warn(self, e, text, label='Warning:'):
-        if self.options.verbose or not self.silenced(e, text):
+        if self.options.verbose or not (self.silenced(e, text) or self.options.quiet):
             self.log(self.msg(e, label, text))
 
     def err(self, e, text, trace=False):
@@ -1856,8 +1855,7 @@ class BaseV3Writer(object):
         #    xml:base attribute).  The tool may be configurable with a limit on
         #    the depth of recursion.
         try:
-            if not self.options.allow_local_file_access:
-                self.check_includes()
+            self.check_includes()
             self.tree.xinclude()
         except etree.XIncludeError as e:
             self.die(None, "XInclude processing failed: %s" % e)
@@ -1869,8 +1867,10 @@ class BaseV3Writer(object):
         for xinclude in xincludes:
             href = urlparse(xinclude.get('href'))
             if not href.netloc or href.scheme == 'file':
-                error = 'XInclude processing failed: Can not access local file: {}'.format(xinclude.get('href'))
-                self.die(None, error)
+                try:
+                    can_access(self.options, self.xmlrfc.source, href.path)
+                except FileAccessError as error:
+                    self.die(None, error)
 
     def remove_dtd(self):
         # 
